//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

import { BSON } from "bson";
import { RoomOccupancyList } from "@/model/roomOccupancyList.ts";

export async function fetchRoomOccupancy(
  from_date: string,
  to_date: string,
): Promise<RoomOccupancyList> {
  var roomOccupancyList: RoomOccupancyList = new RoomOccupancyList(
    new Date(),
    0,
    0,
    [],
  );

  await fetch("/api/schedule/rooms?from=" + from_date + "&to=" + to_date)
    .then((response) => {
      return response.arrayBuffer();
    })
    .then((roomsResponse: ArrayBuffer | null) => {
      if (roomsResponse == null) {
        return null;
      }
      const data = new Uint8Array(roomsResponse);
      roomOccupancyList = RoomOccupancyList.fromJSON(BSON.deserialize(data));
      return roomOccupancyList;
    });

  return roomOccupancyList;
}
